@@ -8,15 +8,16 @@ class HTML5Tests(unittest.TestCase):
     Test the functions which implement the HTML5 color algorithms.
 
     """
+
     def test_parse_simple_color(self):
         """
         Test implementation of the HTML5 simple color parsing
         algorithm.
         """
         test_pairs = (
-            (u'#ffffff', (255, 255, 255)),
-            (u'#000080', (0, 0, 128)),
-            (u'#daa520', (218, 165, 32))
+            ("#ffffff", (255, 255, 255)),
+            ("#000080", (0, 0, 128)),
+            ("#daa520", (218, 165, 32)),
         )
         for raw, parsed in test_pairs:
             result = webcolors.html5_parse_simple_color(raw)
@@ -30,19 +31,15 @@ class HTML5Tests(unittest.TestCase):
 
         """
         test_values = (
-            u'0099ccc',
-            u'#09c',
-            u'#0000',
-            u'#0000000',
-            u'#0000gg',
-            u'#000000'.encode('ascii')
+            "0099ccc",
+            "#09c",
+            "#0000",
+            "#0000000",
+            "#0000gg",
+            "#000000".encode("ascii"),
         )
         for value in test_values:
-            self.assertRaises(
-                ValueError,
-                webcolors.html5_parse_simple_color,
-                value
-            )
+            self.assertRaises(ValueError, webcolors.html5_parse_simple_color, value)
 
     def test_serialize_simple_color(self):
         """
@@ -51,11 +48,11 @@ class HTML5Tests(unittest.TestCase):
 
         """
         test_pairs = (
-            ((0, 0, 0), u'#000000'),
-            ((0, 0, 128), u'#000080'),
-            ((218, 165, 32), u'#daa520'),
-            (webcolors.IntegerRGB(218, 165, 32), u'#daa520'),
-            (webcolors.HTML5SimpleColor(218, 165, 32), u'#daa520'),
+            ((0, 0, 0), "#000000"),
+            ((0, 0, 128), "#000080"),
+            ((218, 165, 32), "#daa520"),
+            (webcolors.IntegerRGB(218, 165, 32), "#daa520"),
+            (webcolors.HTML5SimpleColor(218, 165, 32), "#daa520"),
         )
         for raw, serialized in test_pairs:
             result = webcolors.html5_serialize_simple_color(raw)
@@ -72,11 +69,11 @@ class HTML5Tests(unittest.TestCase):
         # believable junk strings. Correct output values obtained
         # manually.
         test_pairs = (
-            (u'chucknorris', (192, 0, 0)),
-            (u'Window', (0, 13, 0)),
-            (u'RE|SXLuAse', (224, 0, 224)),
-            (u'+=@FnnWL!Yb}5Dk', (0, 0, 176)),
-            (u'A' * 129, (170, 170, 170))
+            ("chucknorris", (192, 0, 0)),
+            ("Window", (0, 13, 0)),
+            ("RE|SXLuAse", (224, 0, 224)),
+            ("+=@FnnWL!Yb}5Dk", (0, 0, 176)),
+            ("A" * 129, (170, 170, 170)),
         )
         for raw, parsed in test_pairs:
             result = webcolors.html5_parse_legacy_color(raw)
@@ -98,13 +95,7 @@ class HTML5Tests(unittest.TestCase):
         hexadecimal color values.
 
         """
-        test_values = (
-            u'#000',
-            u'#000000',
-            u'#fff',
-            u'#ffffff',
-            u'#000080'
-        )
+        test_values = ("#000", "#000000", "#fff", "#ffffff", "#000080")
         for value in test_values:
             parsed = webcolors.html5_parse_legacy_color(value)
             assert parsed == webcolors.hex_to_rgb(value)
@@ -114,14 +105,6 @@ class HTML5Tests(unittest.TestCase):
         Test error conditions of the HTML5 legacy color parsing algorithm.
 
         """
-        test_values = (
-            u'#000000'.encode('ascii'),
-            u'transparent',
-            u''
-        )
+        test_values = ("#000000".encode("ascii"), "transparent", "")
         for value in test_values:
-            self.assertRaises(
-                ValueError,
-                webcolors.html5_parse_legacy_color,
-                value
-            )
+            self.assertRaises(ValueError, webcolors.html5_parse_legacy_color, value)
