@@ -9,6 +9,7 @@ class NormalizationTests(unittest.TestCase):
     functions.
 
     """
+
     def test_normalize_hex(self):
         """
         Hexadecimal normalization normalizes valid hex color codes to
@@ -16,10 +17,10 @@ class NormalizationTests(unittest.TestCase):
 
         """
         test_pairs = (
-            (u'#0099cc', u'#0099cc'),
-            (u'#0099CC', u'#0099cc'),
-            (u'#09c', u'#0099cc'),
-            (u'#09C', u'#0099cc')
+            ("#0099cc", "#0099cc"),
+            ("#0099CC", "#0099cc"),
+            ("#09c", "#0099cc"),
+            ("#09C", "#0099cc"),
         )
 
         for raw, normalized in test_pairs:
@@ -30,32 +31,16 @@ class NormalizationTests(unittest.TestCase):
         Hex normalization raises ValueError on invalid hex color code.
 
         """
-        test_values = (
-            u'0099cc',
-            '#0000gg',
-            '#0000',
-            '#00000000'
-        )
+        test_values = ("0099cc", "#0000gg", "#0000", "#00000000")
         for value in test_values:
-            self.assertRaises(
-                ValueError,
-                webcolors.normalize_hex,
-                value
-            )
+            self.assertRaises(ValueError, webcolors.normalize_hex, value)
 
     def test_normalize_integer_rgb(self):
         """
         Integer normalization clips to 0-255.
 
         """
-        test_pairs = (
-            (255, 255),
-            (0, 0),
-            (128, 128),
-            (-20, 0),
-            (270, 255),
-            (-0, 0)
-        )
+        test_pairs = ((255, 255), (0, 0), (128, 128), (-20, 0), (270, 255), (-0, 0))
 
         for raw, normalized in test_pairs:
             assert normalized == webcolors._normalize_integer_rgb(raw)
@@ -70,7 +55,7 @@ class NormalizationTests(unittest.TestCase):
             ((0, 0, 0), (0, 0, 0)),
             ((255, 255, 255), (255, 255, 255)),
             ((270, -20, 128), (255, 0, 128)),
-            ((-0, -0, -0), (0, 0, 0))
+            ((-0, -0, -0), (0, 0, 0)),
         )
 
         for triplet, normalized in test_pairs:
@@ -84,13 +69,13 @@ class NormalizationTests(unittest.TestCase):
 
         """
         test_pairs = (
-            (u'0%', u'0%'),
-            (u'100%', u'100%'),
-            (u'62%', u'62%'),
-            (u'-5%', u'0%'),
-            (u'250%', u'100%'),
-            (u'85.49%', u'85.49%'),
-            (u'-0%', u'0%')
+            ("0%", "0%"),
+            ("100%", "100%"),
+            ("62%", "62%"),
+            ("-5%", "0%"),
+            ("250%", "100%"),
+            ("85.49%", "85.49%"),
+            ("-0%", "0%"),
         )
 
         for raw, normalized in test_pairs:
@@ -102,10 +87,10 @@ class NormalizationTests(unittest.TestCase):
 
         """
         test_pairs = (
-            ((u'50%', u'50%', u'50%'), (u'50%', u'50%', u'50%')),
-            ((u'0%', u'100%', u'0%'), (u'0%', u'100%', u'0%')),
-            ((u'-10%', u'250%', u'500%'), (u'0%', u'100%', u'100%')),
-            ((u'-0%', u'-0%', u'-0%'), (u'0%', u'0%', u'0%'))
+            (("50%", "50%", "50%"), ("50%", "50%", "50%")),
+            (("0%", "100%", "0%"), ("0%", "100%", "0%")),
+            (("-10%", "250%", "500%"), ("0%", "100%", "100%")),
+            (("-0%", "-0%", "-0%"), ("0%", "0%", "0%")),
         )
 
         for triplet, normalized in test_pairs:
